
%delete incsim3.out
%diary incsim3.out

% PROJECT:		Healthy, Wealthy, & Wise (AHEAD Data)
% FACULTY:		Dan McFadden
% AUTHOR:		Peter Adams
% LAST UPDATE:		February 10, 2002
% PROGRAM DESC:		Run Incidence Simulation (5): Scenario #3 (Low SES)


% ===========================================================================
% DEPENDENT VARIABLE ORDER (INCIDENCE REGRESSIONS)
% ===========================================================================

% jcancer2(1) jheart2(2) jstroke2(3) tdied2(4) ilung2(5) idiabet2(6)
% ihighbp2(7) iarthrt2(8) jincont2(9) jfall2(10) jhipfrc2(11) proxyw2(12)
% icogim2(13) ipsych2(14) idepres2(15) bmi2(16) smoknow2(17) numadl2(18)
% numiadl2(19) dhlth2(20)


% ===========================================================================
% INITIALIZE VARIABLES
% ===========================================================================

%rand('state',54321);
%randn('state',12345);

xxsim(:,4)=1;	% q1wb1: 1st wealth quartile
xxsim(:,5)=0;	% q4wb1: 4th wealth quartile
xxsim(:,6)=1;	% q1ib1: 1st income quartile
xxsim(:,7)=0;	% q4ib1: 4th income quartile
xxsim(:,8)=0;	% hs: high school indicator
xxsim(:,9)=0;	% coll: college indicator
xxsim(:,10)=1;	% hoodpf: nhood condition poor/fair
xxsim(:,11)=1;	% condpf: hhold condition poor/fair

xxsim2=[logm1 xxsim(:,1:38) zeros(NOBS,24)];
pr1=[xxsim(:,18:20) mort1 xxsim(:,21:32) xxsim(:,35:38)];
nx2=zeros(NOBS,1);
dhlth2=zeros(NOBS,1);


% ===========================================================================
% GENERATE NEW INCIDENCE   [local: k ic2 xb2 p2 r nx2 th2 isigma e ystar2]
% ===========================================================================

disp(' ');
disp('===============================================================');
disp('SIMULATED NEW INCIDENCE OF HEALTH CONDITIONS');
disp('===============================================================');

for k=1:20;
   
   if k==5 | k==6 | k==7 | k==8 | k==13 | k==14 | k==15;
      VALID=find(mort2(:,1)==0 & pr1(:,k)==0);
      VALID_f=find(mort2(:,1)==0 & pr1(:,k)==0 & male(:,1)==0);
      VALID_m=find(mort2(:,1)==0 & pr1(:,k)==0 & male(:,1)==1);
   else;
      VALID=find(mort2(:,1)==0);
      VALID_f=find(mort2(:,1)==0 & male(:,1)==0);
      VALID_m=find(mort2(:,1)==0 & male(:,1)==1);
   end;
   
   if k==4;
      ic2=((male==0).*(pr1(:,k)==0)*IC{1,k}(1,:)) + ...
         ((male==0).*(pr1(:,k)==1)*IC{1,k}(2,:)) + ...
         ((male==1).*(pr1(:,k)==0)*IC{2,k}(1,:)) + ...
         ((male==1).*(pr1(:,k)==1)*IC{2,k}(2,:));
      xb2=sum(xxsim2(:,:).*ic2(:,:),2);
      r=rand(NOBS,1);  
      e=norminv(r.^gamma);
      ystar2=xb2+e;
      nx2(VALID,1)=(ystar2(VALID,1)>0);    
   elseif k==12|k==17|k==20;
      ic2=((male==0).*(pr1(:,k)==0)*IC{1,k}(1,:)) + ...
         ((male==0).*(pr1(:,k)==1)*IC{1,k}(2,:)) + ...
         ((male==1).*(pr1(:,k)==0)*IC{2,k}(1,:)) + ...
         ((male==1).*(pr1(:,k)==1)*IC{2,k}(2,:));
      xb2=sum(xxsim2(:,:).*ic2(:,:),2);
      p2=(pr1(:,k)==0).*normcdf(-xb2,0,1).^delta + ...
         (pr1(:,k)==1).*(1-(normcdf(xb2,0,1).^delta));
      r=rand(NOBS,1);  
      nx2(VALID,1)=(r(VALID,1)>p2(VALID,1));
   elseif k==16;
      ic2=(male==0)*IC{1,k}(1,:)+(male==1)*IC{2,k}(1,:);
      xb2=sum(xxsim2(:,:).*ic2(:,:),2);
      isigma=((male(:,1)==0)*isigma_f)+((male(:,1)==1)*isigma_m);
      r=randn(NOBS,1);
      nx2(VALID,1)=xb2(VALID,1)+r(VALID,1).*isigma(VALID,1);
   elseif k==18;
      xxsim2=cat(2,logm2,xxsim2(:,2:63));
      ic2=(male==0)*IC{1,k}(1,:)+(male==1)*IC{2,k}(1,:);
      xb2=sum(xxsim2(:,:).*ic2(:,:),2);
      th2=((male(:,1)==0)*IC{1,k}(1,58:63))+((male(:,1)==1)*IC{2,k}(1,58:63));
      p2=normcdf(th2-xb2*ones(1,6),0,1); 
      r=rand(NOBS,1)*ones(1,6);
      nx2(VALID,1)=sum((r(VALID,:)>p2(VALID,:)),2);
   elseif k==19;
      xxsim2=cat(2,logm2,xxsim2(:,2:63));
      ic2=(male==0)*IC{1,k}(1,:)+(male==1)*IC{2,k}(1,:);
      xb2=sum(xxsim2(:,:).*ic2(:,:),2);
      th2=((male(:,1)==0)*IC{1,k}(1,58:62))+((male(:,1)==1)*IC{2,k}(1,58:62));
      p2=normcdf(th2-xb2*ones(1,5),0,1); 
      r=rand(NOBS,1)*ones(1,5);
      nx2(VALID,1)=sum((r(VALID,:)>p2(VALID,:)),2);
   else;
      ic2=((male==0).*(pr1(:,k)==0)*IC{1,k}(1,:)) + ...
         ((male==0).*(pr1(:,k)==1)*IC{1,k}(2,:)) + ...
         ((male==1).*(pr1(:,k)==0)*IC{2,k}(1,:)) + ...
         ((male==1).*(pr1(:,k)==1)*IC{2,k}(2,:));
      xb2=sum(xxsim2(:,:).*ic2(:,:),2);
      p2=normcdf(-xb2,0,1).^delta;
      r=rand(NOBS,1);  
      nx2(VALID,1)=(r(VALID,1)>p2(VALID,1));    
   end;
   
   run_out1;
   
   if k<=3;
      xxsim2(:,k+39)=nx2;     
   elseif k==4;
      mort2=nx2+mort1;
      mort2e=e;
   elseif k==16;
      run_bmi;
      xxsim2(:,54)=bmibt2;
      xxsim2(:,55)=bmiws2;
   elseif k>=17 & k<=19;
      xxsim2(:,k+39)=nx2;
   elseif k==20;
      dhlth2=nx2;
   else;
      xxsim2(:,k+38)=nx2;
   end;
   
   xxsim2=cat(2,logm1,xxsim2(:,2:63));
   nx2=zeros(NOBS,1);
   
end;


% ===========================================================================
% RESET SIMULATED INCIDENCE MATRIX
% ===========================================================================

xxsim2=[xxsim2(:,2:58) dhlth2];
col_inc=[39:52 55:58];


   % ------------------------------------------------------------------------
   % SIMULATED INCIDENCE MATRIX VARIABLE ORDER		[xxsim2]
   % ------------------------------------------------------------------------

	% one(1) as70m1(2) as80m1(3) q1wb1(4) q4wb1(5) q1ib1(6) q4ib1(7) hs(8)
   % coll(9) hoodpf(10) condpf(11) nevmarr1(12) widow1(13) divsep1(14)
   % magedie1(15) pagedie1(16) smokev(17)
   
   % cancer1(18) heart1(19) stroke1(20) lung1(21) diabet1(22) highbp1(23)
   % arthrt1(24) incont1(25) fall1(26) hipfrc1(27) proxyw1(28) cogim1(29)
   % psych1(30) depres1(31) bmi1(32) lobmi1(33) hibmi1(34) smoknow1(35)
   % numadl1(36) numiadl1(37) dhlth1(38)
   
   % jcancer2(39) jheart2(40) jstroke2(41) ilung2(42) idiabet2(43)
   % ihighbp2(44) iarthrt2(45) jincont2(46) jfall2(47) jhipfrc2(48)
   % proxyw2(49) icogim2(50) ipsych2(51) idepres2(52) bmibt2(53) bmiws2(54)
   % smoknow2(55) numadl2(56) numiadl2(57) dhlth2(58)
   

% ===========================================================================
% SET SAMPLE
% ===========================================================================

r_mort2=mort2(r_row,1);
s_mort2=zeros(size(r_row,1),1);
s_mort2(c_row,1)=mort2(sp_row,1);

r_married2=r_married1.*(r_mort2==0).*(s_mort2==0);
s_married2=r_married2;
married2=[r_married2; s_married2(c_row,1)];
widow2=abs(married2-married1);

r_sample=3-(r_married2+r_married1);
s_sample=r_sample;
sample=[r_sample; s_sample(c_row,1)];


% ===========================================================================
% CLEAR LOCAL VARIABLES
% ===========================================================================

clear ans k ic2 xb2 p2 r nx2 th2 isigma e ystar2 temp1 temp2;

%diary off
