
%delete prevsim.out
%diary prevsim.out

% PROJECT:		Healthy, Wealthy, & Wise (AHEAD Data)
% FACULTY:		Daniel McFadden
% AUTHOR:		Peter Adams
% LAST UPDATE:		February 19, 2002
% PROGRAM DESC:		Run Prevalence Simulation (4)


clear all;
load exogdata;


% ===========================================================================
% DEPENDENT VARIABLE ORDER (PREVALENCE REGRESSIONS)
% ===========================================================================

% cancer1(1) heart1(2) stroke1(3) lung1(4) diabet1(5) highbp1(6)
% arthrt1(7) incont1(8) fall1(9) hipfrc1(10) proxyw1(11) cogim1(12)
% psych1(13) depres1(14) bmi1(15) smoknow1(16) numadl1(17) numiadl1(18)
% dhlth1(19)


% ===========================================================================
% INITIALIZE VARIABLES
% ===========================================================================

rand('state',12345);
randn('state',54321);


% ===========================================================================
% GENERATE PREVALENCE	[local vars: n pc xb p1 r nx th xbth psigma]
% ===========================================================================

xx=XX(:,1:17);

disp('====================================================================');
disp('SIMULATED, INITIAL PREVALENCE OF HEALTH CONDITIONS');
disp('====================================================================');

res={};
for n=1:19;
   
%   disp(' ');
%   disp(upper(prev_txt(n,1)));
%   disp('----------------------------------------------------------');
   
   pc=(male==0)*PC{1,n}(1,1:n+16)+(male==1)*PC{2,n}(1,1:n+16);
   xb=sum(xx.*pc,2);
   
   if n==15;   % BMI
      psigma=((male==0)*psigma_f)+((male==1)*psigma_m);
      nx=xb+(randn(NOBS,1).*psigma);
   elseif n==17;   % ADL
      th=((male==0)*PC{1,n}(1,35:40))+((male==1)*PC{2,n}(1,35:40));
      xbth=normcdf(th-xb*ones(1,6),0,1); 
      r=rand(NOBS,1)*ones(1,6);
      nx=sum((r>xbth),2);
   elseif n==18;   % IADL            
      th=((male==0)*PC{1,n}(1,35:39))+((male==1)*PC{2,n}(1,35:39));
      xbth=normcdf(th-xb*ones(1,5),0,1); 
      r=rand(NOBS,1)*ones(1,5);
      nx=sum((r>xbth),2);
   else;
      p1=normcdf(-xb,0,1);
      r=rand(NOBS,1);
      nx=(r>p1);
   end;
   
   check1{1,1}(n+1,1)=NOBS;
   check1{2,1}(n+1,1)=size(VALID_f,1);
   check1{3,1}(n+1,1)=size(VALID_m,1);
   temp1=[check1{1,1}(n+1,1) check1{2,1}(n+1,1) check1{3,1}(n+1,1)]; 
   
   check2{1,1}(n+1,1)=mean(nx,1);
   check2{2,1}(n+1,1)=mean(nx(VALID_f,1),1);
   check2{3,1}(n+1,1)=mean(nx(VALID_m,1),1);
   temp2=[check2{1,1}(n+1,1) check2{2,1}(n+1,1) check2{3,1}(n+1,1)]; 

%   disp(temp1);
%   disp(temp2);
   res=[res;[ upper(prev_txt(n,1)) num2cell([temp1 temp2])]];
   
   xx=[xx nx];
   
end;

disp(res);

xxsim=xx;


% ===========================================================================
% GENERATE BMI PREVALENCE VARIABLES
% ===========================================================================

lobmi1=(xxsim(:,32)<20).*(20-xxsim(:,32));
hibmi1=(xxsim(:,32)>25).*(xxsim(:,32)-25);


% ===========================================================================
% SET CHECK VARIABLES (WEALTH/INCOME)
% ===========================================================================

check1{1,1}(21,1)=size(r_row,1);

check2{1,1}(21,1)=sum(xxsim(r_row,4),1)/size(r_row,1);
check2{1,1}(22,1)=sum(xxsim(r_row,5),1)/size(r_row,1);
check2{1,1}(23,1)=sum(xxsim(r_row,6),1)/size(r_row,1);
check2{1,1}(24,1)=sum(xxsim(r_row,7),1)/size(r_row,1);

check2{1,1}(25,1)=prctile(c_2w1(r_row,1),25);
check2{1,1}(26,1)=median(c_2w1(r_row,1));
check2{1,1}(27,1)=prctile(c_2w1(r_row,1),75);

check2{1,1}(28,1)=prctile(c_2l1(r_row,1),25);
check2{1,1}(29,1)=median(c_2l1(r_row,1));
check2{1,1}(30,1)=prctile(c_2l1(r_row,1),75);

check2{1,1}(31,1)=prctile(c_2n1(r_row,1),25);
check2{1,1}(32,1)=median(c_2n1(r_row,1));
check2{1,1}(33,1)=prctile(c_2n1(r_row,1),75);

check2{1,1}(34,1)=prctile(c_2i1(r_row,1),25);
check2{1,1}(35,1)=median(c_2i1(r_row,1));
check2{1,1}(36,1)=prctile(c_2i1(r_row,1),75);


% ===========================================================================
% RESET PREVALENCE MATRIX
% ===========================================================================

xxsim=[xxsim(:,1:32) lobmi1 hibmi1 xxsim(:,33:36)];
col_prev=[18:32 35:38];
   
   
   % ------------------------------------------------------------------------
   % SIMULATED PREVALENCE MATRIX VARIABLE ORDER		[xxsim]
   % ------------------------------------------------------------------------

	% one(1) as70m1(2) as80m1(3) q1wb1(4) q4wb1(5) q1ib1(6) q4ib1(7) hs(8)
   % coll(9) hoodpf(10) condpf(11) nevmarr1(12) widow1(13) divsep1(14)
   % magedie1(15) pagedie1(16) smokev(17)
   
   % cancer1(18) heart1(19) stroke1(20) lung1(21) diabet1(22) highbp1(23)
   % arthrt1(24) incont1(25) fall1(26) hipfrc1(27) proxyw1(28) cogim1(29)
   % psych1(30) depres1(31) bmi1(32) lobmi1(33) hibmi1(34) smoknow1(35)
   % numadl1(36) numiadl1(37) dhlth1(38)
   

% ===========================================================================
% SAVE GENERATED PREVALENCE DATASET
% ===========================================================================

clear ans n pc xb p1 r nx th xbth psigma xx temp1 temp2;

cwd = pwd;
cd(tempdir);
pack;
cd(cwd);
clear cwd;

save prevdata.mat

%diary off
