
%delete wlthsim.out
%diary wlthsim.out

% PROJECT:			Healthy, Wealthy, & Wise (AHEAD Data)
% FACULTY:			Daniel McFadden
% AUTHOR:			Peter Adams
% LAST UPDATE:			February 18, 2003
% PROGRAM DESC:			Simulate Wealth & Income (6)


% ===========================================================================
% INITIALIZE VARIABLES
% ===========================================================================

if year<=8;
   R=.15;
else
   R=.07;
end;

W1=cW*c_2w1-dW;				%normalized Total Wealth
zW1=1./(1+exp(-W1));			%logistic Total Wealth	

r_zW1=zW1(r_row,1);
s_zW1=zeros(size(r_row,1),1);
s_zW1(c_row,1)=zW1(sp_row,1);

r_zWL1=zWL1(r_row,1);
s_zWL1=zeros(size(r_row,1),1);
s_zWL1(c_row,1)=zWL1(sp_row,1);

r_zWN1=zWN1(r_row,1);
s_zWN1=zeros(size(r_row,1),1);
s_zWN1(c_row,1)=zWN1(sp_row,1);

r_zN1=zN1(r_row,1);
s_zN1=zeros(size(r_row,1),1);
s_zN1(c_row,1)=zN1(sp_row,1);

%run_stats;

% ===========================================================================
% CALIBRATION OF CONSTANT
% ===========================================================================

cal_coupL=0.991;	% -0.022
cal_spdiL=1.045;	% -0.116
cal_singL=0.800;	% -0.120

cal_coupNL=1.058;	% -0.022
cal_spdiNL=1.113;	% -0.056
cal_singNL=0.876;	% -0.022

cal_coupN=0.965;	% -0.024
cal_spdiN=1.543;	% -0.026
cal_singN=0.929;	% -0.006

% ===========================================================================
% SET INDEPENDENT VARIABLE MATRIX	[xxsim3, xxsim4]
% ===========================================================================

r_xxsim2=xxsim2(r_row,:);
s_xxsim2=zeros(size(r_row,1),size(xxsim2,2));
s_xxsim2(c_row,:)=xxsim2(sp_row,:);

   % ------------------------------------------------------------------------
   % COUPLES & SPDIED
   % ------------------------------------------------------------------------
   
   r_xxsim3=[r_xxsim2(:,1) r_zWL1 r_zWN1 r_xxsim2(:,6:7) ...
         r_xxsim2(:,10:11) r_dnhous1 r_xxsim2(:,8:9) r_xxsim2(:,2:3) ...
         r_xxsim2(:,15:31) r_xxsim2(:,33:58) s_xxsim2(:,8:9) ...
         s_xxsim2(:,2:3) s_xxsim2(:,15:31) s_xxsim2(:,33:58)];
   
   s_xxsim3=[s_xxsim2(:,1) s_zWL1 s_zWN1 s_xxsim2(:,6:7) ...
         s_xxsim2(:,10:11) s_dnhous1 s_xxsim2(:,8:9) s_xxsim2(:,2:3) ...
         s_xxsim2(:,15:31) s_xxsim2(:,33:58) r_xxsim2(:,8:9) ...
         r_xxsim2(:,2:3) r_xxsim2(:,15:31) r_xxsim2(:,33:58)];
   
   xxsim3=[r_xxsim3; s_xxsim3(c_row,:)];
   
   % ------------------------------------------------------------------------
   % SINGLES
   % ------------------------------------------------------------------------
   
   xxsim4=[xxsim3(:,1:12) xxsim2(:,12:14) xxsim3(:,13:55)];
   
   
% ===========================================================================
% SET VALID SAMPLE
% ===========================================================================

resp=[ones(size(r_row,1),1); zeros(size(c_row,1),1)];
valid_w=(resp.*(sample==1))+(sample==2 | sample==3);
VALID2=find(mort2(:,1)==0 & valid_w==1);


% ===========================================================================
% SIMULATE LIQUID WEALTH
% ===========================================================================

% ------------------------------------------------------------------------
% INITIALIZE VARIABLES
% ------------------------------------------------------------------------

K=(zWL1.*(1-zWL1));
xxsim3k=K*ones(1,102).*xxsim3;
xxsim4k=K*ones(1,58).*xxsim4;
yhat=zeros(NOBS,1);

% ------------------------------------------------------------------------
% COUPLES & SPDIED
% ------------------------------------------------------------------------

coefmc=WC{1,2}(1,1:102);
coeffc=WC{1,2}(1,[1:8 56:102 9:55]);
coefmc(1)=coefmc(1)*cal_coupL;
coeffc(1)=coeffc(1)*cal_coupL;

coefmd=WC{2,2}(1,1:102);
coeffd=WC{2,2}(1,[1:8 56:102 9:55]);
coefmd(1)=coefmd(1)*cal_spdiL;
coeffd(1)=coeffd(1)*cal_spdiL;

wc1=(sample==1).*(male==1)*coefmc + ...
    (sample==1).*(male==0)*coeffc + ...
    (sample==2).*(male==1)*coefmd + ...
    (sample==2).*(male==0)*coeffd;

h=xxsim3k.*wc1;
smpl=find(sample==1 | sample==2);
cols=[1 2 3];
%[min(h(smpl,cols));prctile(h(smpl,cols),25);prctile(h(smpl,cols),50);prctile(h(smpl,cols),75);max(h(smpl,cols))]
%[prctile(sum(h(:,[1 2]),2),25);prctile(sum(h(:,[1 2]),2),50);prctile(sum(h(:,[1 2]),2),75)]
xb1=sum(h,2);

% ------------------------------------------------------------------------
% SINGLES
% ------------------------------------------------------------------------

coefms=WC{3,2}(1,1:58);
coeffs=WC{3,2}(1,[59:116]);
coefms(1)=coefms(1)*cal_singL;
coeffs(1)=coeffs(1)*cal_singL;

wc2=(sample==3).*(male==1)*coefms + ...
    (sample==3).*(male==0)*coeffs;

h=xxsim4k.*wc2;
smpl=find(sample==3);
cols=[1 2 3];
%[min(h(smpl,cols));prctile(h(smpl,cols),25);prctile(h(smpl,cols),50);prctile(h(smpl,cols),75);max(h(smpl,cols))]
%[prctile(sum(h(:,[1 2]),2),25);prctile(sum(h(:,[1 2]),2),50);prctile(sum(h(:,[1 2]),2),75)]
xb2=sum(h,2);

% ------------------------------------------------------------------------
% PREDICTED VALUES
% ------------------------------------------------------------------------

xb=xb1+xb2;
sigma=(sample==1)*WC{1,2}(1,103) + ...
   (sample==2)*WC{2,2}(1,103) + ...
   (sample==3)*WC{3,2}(1,117);
r=randn(NOBS,1);
%yhat(VALID2,1)=xb(VALID2,1)+r(VALID2,1).*sigma(VALID2,1);
yhat=xb+r.*sigma;

%r_yhat=yhat(r_row,1);
%s_yhat=zeros(size(r_row,1),1);
%s_yhat(c_row)=yhat(sp_row,1);

%r_yhat=r_yhat+s_yhat;
%s_yhat=r_yhat;
%yhat=[r_yhat; s_yhat(c_row,1)];

% ------------------------------------------------------------------------
% SET VARIABLES
% ------------------------------------------------------------------------

zWL2=zeros(NOBS,1);
zWL2(VALID2,1)=12*yhat(VALID2,1) + zWL1(VALID2,1) + ...
   R*K(VALID2,1).*(WL1(VALID2,1)+dWL);

%stats1(zWL2(VALID2));

r_zWL2=zWL2(r_row,1);
s_zWL2=zeros(size(r_row,1),1);
s_zWL2(c_row,1)=zWL2(sp_row,1);

r_zWL2=r_zWL2+s_zWL2;
s_zWL2=r_zWL2;
zWL2=[r_zWL2; s_zWL2(c_row,1)];

%temp1=find(zWL2>=1);
%temp2=find(zWL2<1);
%zWL2(temp1,1)=max(zWL2(temp2,1));

%temp3=find(zWL2<=0);
%temp4=find(zWL2>0);
%zWL2(temp3,1)=min(zWL2(temp4,1));

temp1=find(zWL2>1);
zWL2(temp1,1)=1;
temp2=find(zWL2<0);
zWL2(temp2,1)=0;

VALID=find(mort2(:,1)==0);
WL2=zeros(NOBS,1);
WL2(VALID,1)=log(zWL2(VALID,1))-log(1-zWL2(VALID,1));

WL2(temp1,1)=max(WL1);
WL2(temp2,1)=min(WL1);

c_2l2=zeros(NOBS,1);
c_2l2(VALID,1)=(WL2(VALID,1)+dWL)./cWL;

%run_statsWL;		% summary statistics LIQUID WEALTH (by sample)


% ===========================================================================
% SIMULATE NON-LIQUID WEALTH
% ===========================================================================

% ------------------------------------------------------------------------
% INITIALIZE VARIABLES
% ------------------------------------------------------------------------

K=(zWN1.*(1-zWN1));
xxsim3k=K*ones(1,102).*xxsim3;
xxsim4k=K*ones(1,58).*xxsim4;
yhat=zeros(NOBS,1);

% ------------------------------------------------------------------------
% COUPLES & SPDIED
% ------------------------------------------------------------------------

coefmc=WC{1,3}(1,1:102);
coeffc=WC{1,3}(1,[1:8 56:102 9:55]);
coefmc(1)=coefmc(1)*cal_coupNL;
coeffc(1)=coeffc(1)*cal_coupNL;

coefmd=WC{2,3}(1,1:102);
coeffd=WC{2,3}(1,[1:8 56:102 9:55]);
coefmd(1)=coefmd(1)*cal_spdiNL;
coeffd(1)=coeffd(1)*cal_spdiNL;

wc1=(sample==1).*(male==1)*coefmc + ...
    (sample==1).*(male==0)*coeffc + ...
    (sample==2).*(male==1)*coefmd + ...
    (sample==2).*(male==0)*coeffd;

h=xxsim3k.*wc1;
smpl=find(sample==1 | sample==2);
cols=[1 2 3];
%[min(h(smpl,cols));prctile(h(smpl,cols),25);prctile(h(smpl,cols),50);prctile(h(smpl,cols),75);max(h(smpl,cols))]
%[prctile(sum(h(:,[1 2]),2),25);prctile(sum(h(:,[1 2]),2),50);prctile(sum(h(:,[1 2]),2),75)]
xb1=sum(h,2);

% ------------------------------------------------------------------------
% SINGLES
% ------------------------------------------------------------------------

coefms=WC{3,3}(1,1:58);
coeffs=WC{3,3}(1,[59:116]);
coefms(1)=coefms(1)*cal_singNL;
coeffs(1)=coeffs(1)*cal_singNL;

wc2=(sample==3).*(male==1)*coefms + ...
    (sample==3).*(male==0)*coeffs;

h=xxsim4k.*wc2;
smpl=find(sample==3);
cols=[1 2 3];
%[min(h(smpl,cols));prctile(h(smpl,cols),25);prctile(h(smpl,cols),50);prctile(h(smpl,cols),75);max(h(smpl,cols))]
%[prctile(sum(h(:,[1 2]),2),25);prctile(sum(h(:,[1 2]),2),50);prctile(sum(h(:,[1 2]),2),75)]
xb2=sum(h,2);

% ------------------------------------------------------------------------
% PREDICTED VALUES
% ------------------------------------------------------------------------

xb=xb1+xb2;
sigma=(sample==1)*WC{1,3}(1,103) + ...
   (sample==2)*WC{2,3}(1,103) + ...
   (sample==3)*WC{3,3}(1,117);
r=randn(NOBS,1);
%yhat(VALID2,1)=xb(VALID2,1)+r(VALID2,1).*sigma(VALID2,1);
yhat=xb+r.*sigma;

%r_yhat=yhat(r_row,1);
%s_yhat=zeros(size(r_row,1),1);
%s_yhat(c_row)=yhat(sp_row,1);

%r_yhat=r_yhat+s_yhat;
%s_yhat=r_yhat;
%yhat=[r_yhat; s_yhat(c_row,1)];

% ------------------------------------------------------------------------
% SET VARIABLES
% ------------------------------------------------------------------------

zWN2=zeros(NOBS,1);
zWN2(VALID2,1)=12*yhat(VALID2,1) + zWN1(VALID2,1) + ...
   R*K(VALID2,1).*(WN1(VALID2,1)+dWN);

%stats1(zWN2(VALID2));

r_zWN2=zWN2(r_row,1);
s_zWN2=zeros(size(r_row,1),1);
s_zWN2(c_row,1)=zWN2(sp_row,1);

r_zWN2=r_zWN2+s_zWN2;
s_zWN2=r_zWN2;
zWN2=[r_zWN2; s_zWN2(c_row,1)];

%temp1=find(zWN2>=1);
%temp2=find(zWN2<1);
%zWN2(temp1,1)=max(zWN2(temp2,1));

%temp3=find(zWN2<=0);
%temp4=find(zWN2>0);
%zWN2(temp3,1)=min(zWN2(temp4,1));

temp1=find(zWN2>1);
zWN2(temp1,1)=1;
temp2=find(zWN2<0);
zWN2(temp2,1)=0;

VALID=find(mort2(:,1)==0);
WN2=zeros(NOBS,1);
WN2(VALID,1)=log(zWN2(VALID,1))-log(1-zWN2(VALID,1));

%[size(temp1,1) size(temp2,1)]

WN2(temp1,1)=max(WN1);
WN2(temp2,1)=min(WN1);

c_2n2=zeros(NOBS,1);
c_2n2(VALID,1)=(WN2(VALID,1)+dWN)./cWN;

%run_statsWN;		% summary statistics NON-LIQUID WEALTH (by sample)


% ===========================================================================
% GENERATE INCOME
% ===========================================================================

% ------------------------------------------------------------------------
% INITIALIZE VARIABLES
% ------------------------------------------------------------------------

xxsim3k=[xxsim3(:,1) zW1 xxsim3(:,4:102)];
xxsim4k=[xxsim4(:,1) zW1 xxsim4(:,4:58)];
yhat=zeros(NOBS,1);

% ------------------------------------------------------------------------
% COUPLES & SPDIED
% ------------------------------------------------------------------------

coefmc=NC{1,1}(1,1:101);
coeffc=NC{1,1}(1,[1:7 55:101 8:54]);
coefmc(1)=coefmc(1)*cal_coupN;
coeffc(1)=coeffc(1)*cal_coupN;

coefmd=NC{2,1}(1,1:101);
coeffd=NC{2,1}(1,[1:7 55:101 8:54]);
coefmd(1)=coefmd(1)*cal_spdiN;
coeffd(1)=coeffd(1)*cal_spdiN;

nc1=(sample==1).*(male==1)*coefmc + ...
    (sample==1).*(male==0)*coeffc + ...
    (sample==2).*(male==1)*coefmd + ...
    (sample==2).*(male==0)*coeffd;

h=xxsim3k.*nc1;   
smpl=find(sample==1 | sample==2);
cols=[1 2 3];
%[min(h(smpl,cols));prctile(h(smpl,cols),25);prctile(h(smpl,cols),50);prctile(h(smpl,cols),75);max(h(smpl,cols))]
%[prctile(sum(h(:,[1 2]),2),25);prctile(sum(h(:,[1 2]),2),50);prctile(sum(h(:,[1 2]),2),75)]
xb1=sum(h,2);

% ------------------------------------------------------------------------
% SINGLES
% ------------------------------------------------------------------------

coefms=NC{3,1}(1,1:57);
coeffs=NC{3,1}(1,[58:114]);   
coefms(1)=coefms(1)*cal_singN;
coeffs(1)=coeffs(1)*cal_singN;

nc2=(sample==3).*(male==1)*coefms + ...
    (sample==3).*(male==0)*coeffs;

h=xxsim4k.*nc2;
smpl=find(sample==3);
cols=[1 2 3];
%[min(h(smpl,cols));prctile(h(smpl,cols),25);prctile(h(smpl,cols),50);prctile(h(smpl,cols),75);max(h(smpl,cols))]
%[prctile(sum(h(:,[1 2]),2),25);prctile(sum(h(:,[1 2]),2),50);prctile(sum(h(:,[1 2]),2),75)]
xb2=sum(h,2);

% ------------------------------------------------------------------------
% PREDICTED VALUES
% ------------------------------------------------------------------------

xb=xb1+xb2;
sigma=(sample==1)*NC{1,1}(1,102) + ...
   (sample==2)*NC{2,1}(1,102) + ...
   (sample==3)*NC{3,1}(1,115);
r=randn(NOBS,1);
%yhat(VALID2,1)=xb(VALID2,1)+r(VALID2,1).*sigma(VALID2,1);
yhat=xb+r.*sigma;

%r_yhat=yhat(r_row,1);
%s_yhat=zeros(size(r_row,1),1);
%s_yhat(c_row)=yhat(sp_row,1);

%r_yhat=r_yhat+s_yhat;
%s_yhat=r_yhat;
%yhat=[r_yhat; s_yhat(c_row,1)];

% ------------------------------------------------------------------------
% SET VARIABLES
% ------------------------------------------------------------------------

zN2=zeros(NOBS,1);
zN2(VALID2,1)=yhat(VALID2,1)+zN1(VALID2,1);

%stats1(zN2(VALID2));

r_zN2=zN2(r_row,1);
s_zN2=zeros(size(r_row,1),1);
s_zN2(c_row,1)=zN2(sp_row,1);

r_zN2=r_zN2+s_zN2;
s_zN2=r_zN2;
zN2=[r_zN2; s_zN2(c_row,1)];

%temp1=find(zN2>=1);
%temp2=find(zN2<1);
%zN2(temp1,1)=max(zN2(temp2,1));

%temp3=find(zN2<=0);
%temp4=find(zN2>0);
%zN2(temp3,1)=min(zN2(temp4,1));

temp1=find(zN2>1);
zN2(temp1,1)=1;
temp2=find(zN2<0);
zN2(temp2,1)=0;

VALID=find(mort2(:,1)==0);
N2=zeros(NOBS,1);
N2(VALID,1)=log(zN2(VALID,1))-log(1-zN2(VALID,1));

%[size(temp1,1) size(temp2,1)]

N2(temp1,1)=max(N1);
N2(temp2,1)=min(N1);

c_2i2=zeros(NOBS,1);
c_2i2(VALID,1)=(N2(VALID,1)+dN)./cN;
temp1=find(c_2i2<0);
c_2i2(temp1,1)=0;

%run_statsN;		% summary statistics INCOME (by sample)


% ===========================================================================
% CLEAR LOCAL VARIABLES
% ===========================================================================

clear wc1 wc2 xb1 xb2 xb sigma r yhat nc1 nc2 temp1 temp2 ...
	xxsim3k xxsim4k xxsim3 xxsim4;

%diary off
